==> estateplat-common-1.2.3-20180516.013157-85-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbzdFbf.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: zx
 * Date: 15-5-8
 * Time: 下午7:16
 * To change this template use File | Settings | File Templates.
 * dos:土地承包经营权----发包方
 */
public class DjsjCbzdFbf {
    private String cbzdFbfIndex;
    private String fbfmc;
    private String fbffzrxm;
    private String fbffzrdz;
    private String lxdh;
    private String yzbm;
    private String fzrzjlx;
    private String fzrzjhm;
    private Date gxrq;
    private String zddcbIndex;

    public String getCbzdFbfIndex() {
        return cbzdFbfIndex;
    }

    public void setCbzdFbfIndex(String cbzdFbfIndex) {
        this.cbzdFbfIndex = cbzdFbfIndex;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public String getFbffzrxm() {
        return fbffzrxm;
    }

    public void setFbffzrxm(String fbffzrxm) {
        this.fbffzrxm = fbffzrxm;
    }

    public String getFbffzrdz() {
        return fbffzrdz;
    }

    public void setFbffzrdz(String fbffzrdz) {
        this.fbffzrdz = fbffzrdz;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getYzbm() {
        return yzbm;
    }

    public void setYzbm(String yzbm) {
        this.yzbm = yzbm;
    }

    public String getFzrzjlx() {
        return fzrzjlx;
    }

    public void setFzrzjlx(String fzrzjlx) {
        this.fzrzjlx = fzrzjlx;
    }

    public String getFzrzjhm() {
        return fzrzjhm;
    }

    public void setFzrzjhm(String fzrzjhm) {
        this.fzrzjhm = fzrzjhm;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getZddcbIndex() {
        return zddcbIndex;
    }

    public void setZddcbIndex(String zddcbIndex) {
        this.zddcbIndex = zddcbIndex;
    }
}

==> estateplat-common-1.2.4-20210812.021811-836-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbzdFbf.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: zx
 * Date: 15-5-8
 * Time: 下午7:16
 * To change this template use File | Settings | File Templates.
 * dos:土地承包经营权----发包方
 */
public class DjsjCbzdFbf {
    private String cbzdFbfIndex;
    private String fbfmc;
    private String fbffzrxm;
    private String fbffzrdz;
    private String lxdh;
    private String yzbm;
    private String fzrzjlx;
    private String fzrzjhm;
    private Date gxrq;
    private String zddcbIndex;
    private String fbfbm;//发包方编码


    public String getFbfbm() {
        return fbfbm;
    }

    public void setFbfbm(String fbfbm) {
        this.fbfbm = fbfbm;
    }
    public String getCbzdFbfIndex() {
        return cbzdFbfIndex;
    }

    public void setCbzdFbfIndex(String cbzdFbfIndex) {
        this.cbzdFbfIndex = cbzdFbfIndex;
    }

    public String getFbfmc() {
        return fbfmc;
    }

    public void setFbfmc(String fbfmc) {
        this.fbfmc = fbfmc;
    }

    public String getFbffzrxm() {
        return fbffzrxm;
    }

    public void setFbffzrxm(String fbffzrxm) {
        this.fbffzrxm = fbffzrxm;
    }

    public String getFbffzrdz() {
        return fbffzrdz;
    }

    public void setFbffzrdz(String fbffzrdz) {
        this.fbffzrdz = fbffzrdz;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getYzbm() {
        return yzbm;
    }

    public void setYzbm(String yzbm) {
        this.yzbm = yzbm;
    }

    public String getFzrzjlx() {
        return fzrzjlx;
    }

    public void setFzrzjlx(String fzrzjlx) {
        this.fzrzjlx = fzrzjlx;
    }

    public String getFzrzjhm() {
        return fzrzjhm;
    }

    public void setFzrzjhm(String fzrzjhm) {
        this.fzrzjhm = fzrzjhm;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getZddcbIndex() {
        return zddcbIndex;
    }

    public void setZddcbIndex(String zddcbIndex) {
        this.zddcbIndex = zddcbIndex;
    }
}
